flowfabric_token.Rd
Set or get the global token used for authentication. If not set, will attempt to obtain one using flowfabric_get_token().
flowfabric_token(refresh = FALSE)
Force refreshes the token if true